<?xml version='1.0'?>
<!DOCTYPE xsl:stylesheet [
<!ENTITY nbsp   "&#160;">
]>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
 
 <xsl:param name="font">times</xsl:param>

<xsl:output method="html"/>

 <!-- The real stylesheet starts here -->
 <xsl:template match="/">
  <html>
   <head>
    <meta http-equiv="Content-type" content="text/html; charset=utf-8"/>
    <title>
     <xsl:for-each select="doc/head/title">
      <xsl:value-of select="."/>
     </xsl:for-each>
    </title>
    <style type="text/css">
       pre.code {font-family: monospace}
       pre {margin-left: 0em}
       ol ol {list-style-type: lower-alpha}
       .math {font-family: 'Arial Unicode MS', 'Lucida Sans Unicode', serif}
       .sub {font-size: 80%; vertical-align: sub}
       .termref {text-decoration: none; color: #606000}
    </style>
   </head>
   <body style="font-family: {$font}">
    <xsl:apply-templates/>
   </body>
  </html>
 </xsl:template>
  
 <xsl:template match="doc|body|div">
  <xsl:apply-templates/>
 </xsl:template>
 
 <xsl:template match="head">
  <div style="text-align: center">
   <xsl:apply-templates/>
  </div>
 </xsl:template>
 
 <xsl:template match="author|date">
  <div>
   <xsl:apply-templates/>
  </div>
 </xsl:template>

 <xsl:template match="head/title">
  <h1>
   <xsl:apply-templates/>
  </h1>
 </xsl:template>

 <xsl:template match="div/title">
  <h2>
   <xsl:choose>
    <xsl:when test="../@id">
     <a name="{../@id}"><xsl:number format="1.1. " level="multiple" count="div"/></a>
    </xsl:when>
    <xsl:otherwise>
   <xsl:number format="1.1. " level="multiple" count="div"/>
    </xsl:otherwise>
   </xsl:choose>
   <xsl:text> </xsl:text>
   <xsl:apply-templates/>
  </h2>
 </xsl:template>

 <xsl:template match="div//div/title" priority="2">
  <h4>
   <xsl:choose>
    <xsl:when test="../@id">
     <a name="{../@id}"><xsl:number format="1.1. " level="multiple" count="div"/></a>
    </xsl:when>
    <xsl:otherwise>
   <xsl:number format="1.1. " level="multiple" count="div"/>
    </xsl:otherwise>
   </xsl:choose>
   <xsl:text> </xsl:text>
   <xsl:apply-templates/>
  </h4>
 </xsl:template>
 
 <xsl:template match="p">
  <p>
   <xsl:apply-templates/>
  </p>
 </xsl:template>
 
 <xsl:template match="image">
  <img border="0" src="{@source}">
   <xsl:attribute name="alt">
    <xsl:choose>
     <xsl:when test="@textGloss">
      <xsl:value-of select="@textGloss"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="."/>
     </xsl:otherwise>
    </xsl:choose>
   </xsl:attribute>
  </img>
 </xsl:template>

 <xsl:template match="note">
  <p style="width: 20%; float: right; clear: right">
   <small><i><xsl:apply-templates/></i></small>
  </p>
 </xsl:template>
 
 <xsl:template match="item/note">
  <div style="margin-left: 2em">
   <small><i><xsl:apply-templates/></i></small>
  </div>
 </xsl:template>
 
 <xsl:template match="emph">
  <i>
   <xsl:apply-templates/>
  </i>
 </xsl:template>
 
 <xsl:template match="note/emph">
  <span style="font-style: normal">
   <xsl:apply-templates/>
  </span>
 </xsl:template>
 
 <xsl:template match="emph[@color]">
  <span style="color: {@color}">
   <xsl:apply-templates/>
  </span>
 </xsl:template>

 <xsl:template match="name">
  <b>
   <xsl:apply-templates/>
  </b>
 </xsl:template>
 
 <xsl:template match="link[@href]">
  <a>
   <xsl:attribute name="href">
    <xsl:value-of select="@href"/>
   </xsl:attribute>
   <xsl:apply-templates/>
  </a>
 </xsl:template>
 
 <xsl:template match="link[@name]">
  <a>
   <xsl:attribute name="name">
    <xsl:value-of select="@name"/>
   </xsl:attribute>
   <xsl:apply-templates/>
  </a>
 </xsl:template>
 
 <xsl:template match="code">
  <code>
   <xsl:apply-templates/>
  </code>
 </xsl:template>

 <xsl:template match="display/node()[self::code and position()=1 and position()=last()]" priority="2">
  <pre class="code">
   <xsl:apply-templates/>
  </pre>
 </xsl:template>
 
 <xsl:template match="display">
  <blockquote>
   <div>
   <xsl:apply-templates/>
   </div>
  </blockquote>
 </xsl:template>


 <xsl:template match="list[@type='defn']">
  <dl>
   <xsl:apply-templates/>
  </dl>
 </xsl:template>

 <xsl:template match="list[@type='defn']/item">
  <xsl:variable name="n" select="translate(@term,' ','_')"/>
   <dt><b>
<a name="{$n}"><xsl:value-of select="@term"/></a>
</b></dt>
   <dd><xsl:apply-templates/></dd>
 </xsl:template>
 
 <xsl:template match="term">
  <a href="#{translate(@def,' ','_')}" class="termref">
   <xsl:text>&#xB7;</xsl:text>
   <xsl:value-of select="@def"/>
   <xsl:text>&#xB7;</xsl:text>
  </a>
 </xsl:template>

 <xsl:template match="list[@type='normal' or not(@type)]">
  <!-- Firefox doesn't do local DTD attr defaults :-) -->
  <ul>
   <xsl:apply-templates/>
  </ul>
 </xsl:template>

 <xsl:template match="list[@type='enum']">
  <ol>
   <xsl:apply-templates/>
  </ol>
 </xsl:template>

 <xsl:template match="list[@type='normal' or @type='enum' or not(@type)]/item">
  <!-- Firefox doesn't do local DTD attr defaults :-) -->
   <li><xsl:apply-templates/></li>
 </xsl:template>

 <xsl:template match="list[@type='naked']">
  <xsl:apply-templates/>
 </xsl:template>
 
 <xsl:template match="list[@type='2col']">
  <xsl:variable name="n" select="count(item)"/>
  <div style="float: left;width: 50%"><xsl:apply-templates select="item[position()&lt;=($n div 2)]"/></div>
  <div style="margin-left: 50%"><xsl:apply-templates select="item[position()>($n div 2)]"/></div>
 </xsl:template>

 <xsl:template match="list[@type='naked' or @type='2col']/item">
  <div>
   <xsl:if test="../@indent">
    <xsl:attribute name="style">
     <xsl:text>margin-left: </xsl:text>
     <xsl:value-of select="../@indent"/>
    </xsl:attribute>
   </xsl:if>
   <xsl:apply-templates/>
  </div>
 </xsl:template>
 
 <xsl:template match="list[@type='tdefn']">
  <table>
   <tbody>
  <xsl:apply-templates/>
   </tbody>
  </table>
 </xsl:template>
 
 <xsl:template match="list[@type='tdefn']/item">
  <tr>
   <td><xsl:value-of select="@term"/></td>
   <td><xsl:apply-templates/></td>
  </tr>
 </xsl:template>
<!-- 
     XHTML

     We just copy any unrecognised stuff, as is.
     This means you can mix XHTML with no-namespace elts and
     get the 'right' effect.
  -->

<xsl:template match="*|@*">
   <xsl:copy>
      <xsl:apply-templates select="* | @* | text()"/>
   </xsl:copy>
</xsl:template>

</xsl:stylesheet>
